@@ -6,7 +6,7 @@ DOCSIS::ConfigFile - Decodes and encodes DOCSIS config files
 
 =head1 VERSION
 
-0.68
+0.69
 
 =head1 DESCRIPTION
 
@@ -73,8 +73,8 @@ like the example below, instead of using numeric OIDs:
   encode_docsis(
     {
       SnmpMibObject => [
-        {oid => "docsDevNmAccessIp.1",             IPADDRESS => "10.0.0.1"},
-        {oid => "docsDevNmAccessIpMask.1",         IPADDRESS => "255.255.255.255"},
+        {oid => "docsDevNmAccessIp.1",     IPADDRESS => "10.0.0.1"},
+        {oid => "docsDevNmAccessIpMask.1", IPADDRESS => "255.255.255.255"},
       ]
     },
   );
@@ -93,7 +93,7 @@ use constant DEBUG => $ENV{DOCSIS_CONFIGFILE_DEBUG} || 0;
 
 use base 'Exporter';
 
-our $VERSION = '0.68';
+our $VERSION = '0.69';
 our @EXPORT_OK = qw( decode_docsis encode_docsis );
 our $DEPTH     = 0;
 
@@ -221,7 +221,8 @@ sub encode_docsis {
   local $args->{depth} = ($args->{depth} || 0) + 1;
   local $DEPTH = $args->{depth} if DEBUG;
 
-  if ($args->{depth} == 1 and delete $data->{MtaConfigDelimiter}) {
+  if ($args->{depth} == 1 and defined $args->{mta_algorithm}) {
+    delete $data->{MtaConfigDelimiter};
     $bytes .= encode_docsis({MtaConfigDelimiter => 1}, {depth => 1});
   }
 
